@@ -15,7 +15,7 @@ else:
     from . import read_config as rc
     from . import anutils as an
 
-__VERSION__ = "0.0.1"
+__VERSION__ = "0.0.3"
 
 """
     A module to analyze cytosim simulations
@@ -159,33 +159,35 @@ class Simulation(list):
         self.properties = {**self.properties, **props, **simul_props}
 
 
-    def analyze(self,frame,*args,analyze={},**kwargs):
+    def analyze(self, frame, *args, analyzer=None, **kwargs):
 
         analysis={}
-        for name,func in analyze.items():
-            analysis[name]=func(frame)
+        if analyzer is not None:
+            for name,func in analyzer.items():
+                analysis[name]=func(frame)
         analysis['frame.id']=frame.id
 
         return analysis
 
 
-    def make_analysis(self,*args, analyze={}, **kwargs):
+    def make_analysis(self,*args, analyzer=None, **kwargs):
         for frame in self:
-            frame.make_analysis(*args,analyze=analyze,**kwargs)
+            frame.make_analysis(*args, analyzer=analyzer, **kwargs)
 
-        self.frames_analysis=an.objects_analysis(self, *args, analyze=analyze, **kwargs)
+        self.frames_analysis = an.objects_analysis(self, *args, analyzer=analyzer, **kwargs)
 
         try:
-            analyze = analyze['simulation']
+            analyzer = analyzer['simulation']
         except:
-            analyze = {}
+            analyzer = None
 
         analysis = {}
-        for name, func in analyze.items():
-            analysis[name] = func(self)
+        if analyzer is not None:
+            for name, func in analyzer.items():
+                analysis[name] = func(self)
 
         if analysis:
             keys = analysis.keys()
             datas = pd.DataFrame(columns=keys)
             datas.loc[self.id] = [analysis[key] for key in keys]
-            self.analysis=datas
+            self.analysis = datas
